;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'mail '("mh-e"))
(custom-add-loads 'mh-hook '("mh-e"))
(custom-add-loads 'mh-buffer '("mh-utils"))
(custom-add-loads 'mh-compose '("mh-comp"))
(custom-add-loads 'mh '("mh-comp" "mh-e" "mh-utils"))

;;; custom-load.el ends here
